@@ -86,44 +86,57 @@ class WalkSFTP:
 
 
     def glob_sftp(self, store_paths = ''):
+        try:
+            if self._glob_count > self.args.get('break_count', np.inf):
+                return None
 
-        if self._glob_count > self.args.get('break_count', np.inf):
-            return None
+            for f in self.list_path(store_paths):
 
-        for f in self.list_path(store_paths):
+                new_fp_or_file = os.path.join(store_paths, f)
+                stat_bool, stat_mtime = self.test_file(new_fp_or_file)
+                stat_mtime = str(stat_mtime)
+                if stat_bool:
 
-            new_fp_or_file = os.path.join(store_paths, f)
-            stat_bool, stat_mtime = self.test_file(new_fp_or_file)
-            stat_mtime = str(stat_mtime)
-            if stat_bool:
-
-                date_filter = (pd.to_datetime(stat_mtime) >= pd.to_datetime(self.start_date)) and (pd.to_datetime(stat_mtime) <= pd.to_datetime(self.end_date) )
+                    date_filter = (pd.to_datetime(stat_mtime) >= pd.to_datetime(self.start_date)) and (pd.to_datetime(stat_mtime) <= pd.to_datetime(self.end_date) )
 
 
-                if date_filter and self.check_in_log(new_fp_or_file, stat_mtime):
-                    self.class_print('{} {} {}'.format(stat_mtime, new_fp_or_file, date_filter))
-                    self._glob_count+=1
-                    self.q.put(new_fp_or_file)
+                    if date_filter and self.check_in_log(new_fp_or_file, stat_mtime):
+                        self.class_print('{} {} {}'.format(stat_mtime, new_fp_or_file, date_filter))
+                        self._glob_count+=1
+                        self.q.put(new_fp_or_file)
 
-                if self._glob_count > self.args.get('break_count', np.inf):
-                    self.class_print('publishing glob break')
-                    self.q.put('break')
-                    return None
+                    if self._glob_count > self.args.get('break_count', np.inf):
+                        self.class_print('publishing glob break')
+                        self.q.put('break')
+                        return None
 
 
-            else:
-                block = False
-                for b in self.blocks:
-                    if b in new_fp_or_file:
-                        block=True
-                        break
+                else:
+                    block = False
+                    for b in self.blocks:
+                        if b in new_fp_or_file:
+                            block=True
+                            break
 
-                if not block:
-                    self.glob_sftp(new_fp_or_file)
+                    if self.must_have != []:
+                        for i in self.must_have:
+                            if i in new_fp_or_file:
+                                block = False
+                                break
+                            else:
+                                block=True
 
-        if store_paths == self.orig_store_paths:
-            self.class_print('publishing glob break')
-            self.q.put('break')
+                    if not block:
+                        self.glob_sftp(new_fp_or_file)
+
+            if store_paths == self.orig_store_paths:
+                self.class_print('publishing glob break')
+                self.q.put('break')
+
+        except Exception as e:
+            self.class_print('glob sftp error')
+            self.class_print(e)
+            sleep(10)
 
     def test_file(self, f):
         for i in range(0, 2):
@@ -217,8 +230,8 @@ class WalkSFTP:
             try:
                 self.get(fp, store_file)
             except Exception as e:
-                print('ERROR ON: {} {}'.format(fp, store_file))
-                print(e)
+                self.class_print('ERROR ON: {} {}'.format(fp, store_file))
+                self.class_print(e)
 
     def exit_q(self):
         self.process_q.put(('break', 'break'))
@@ -274,7 +287,7 @@ class WalkSFTP:
             )
             return None
 
-        print(f'ERROR: {e}')
+        self.class_print(f'ERROR: {e}')
 
     def cleanup(self):
         self._sftp.close()
@@ -413,7 +426,8 @@ class WalkSFTP:
                         self.class_print('still looping process_all_ftp')
                         count = 0
             except Exception as e:
-                print(f'ERROR: {e}')
+                self.class_print(f'ERROR: {e}')
+
 
 
 
@@ -524,10 +538,17 @@ class WalkSFTP:
         sleep_count : int
             number of seconds to wait until process and store threads
             time out. Default None
+        must_have : str/list
+            must have text to download ftp
+
         '''
 
         self.args=args
         self.max_sleep_count = args.get('max_sleep_count', np.inf)
+        self.must_have = args.get('must_have', [])
+        if not isinstance(self.must_have, list):
+            self.must_have = self.must_have.split(',')
+
         self._sleep_time = sleep_time
 
         self._glob_count=0
